(function (document, Drupal) {

  'use strict';

  /*
    Adding 'aria-describedby' attribute to invalid form input elements
    with error message class 'form-item--error-message'.
    And identify the errors using ARIA live regions 'role=alert'.
   */

  Drupal.forma11y = {};

  Drupal.forma11y.findItemParent = function (el) {
    if (el.classList.contains('js-form-item')) {
      return el;
    }

    if (el.classList.contains('js-form-wrapper') || el.parentNode === null) {
      return false;
    }

    return Drupal.forma11y.findItemParent(el.parentNode);
  };

  Drupal.behaviors.forma11y = {
    attach: function (context) {
      const errorMessages = context.querySelectorAll('.form-item--error-message');

      if (errorMessages.length > 0) {
        errorMessages.forEach((errorMessage) => {
          const errorItem = Drupal.forma11y.findItemParent(errorMessage);

          if (errorItem) {
            const errorInput = errorItem.querySelector('[aria-invalid="true"]');

            if (errorInput) {
              const errorMessageId = errorInput.id.concat('-error-message');

              errorMessage.setAttribute('role', 'alert');
              errorMessage.setAttribute('id', errorMessageId);

              errorInput.classList.add('is-forma11y');
              errorInput.setAttribute('aria-describedby', errorMessageId);
            }
          }
        });
      }
    }
  };

})(document, Drupal);
